@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.1100';
+our $VERSION = '0.1101';
 
 use Moo;
 use strictures 2;
@@ -201,7 +201,7 @@ sub process {
                     my $group = join ' ', @group;
                     $self->net->{ $last . '-' . $group }++ if $last;
                     $last = $group;
-                    shift @group;
+                    @group = ();
                 }
                 push @group, $event->[3];
             }
@@ -432,7 +432,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
